==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
var GridFilterDialogViewModelGroupingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridFilterDialogViewModelGroupingDescriptionMetadata, _super);
    function GridFilterDialogViewModelGroupingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.b = function (a) {
        if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        if (a.k(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
            return;
        }
        a.ab(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.c = function (a) {
        a.item("StartIndex", "Number:int");
        a.item("EndIndex", "Number:int");
        a.item("IsOrGrouping", "Boolean");
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.d = function (a) {
        GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
        a.ad("GridFilterDialogViewModelGrouping", function () { return new GridFilterDialogViewModelGroupingDescription(); });
        a.ac("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
}(Base));
export { GridFilterDialogViewModelGroupingDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
var GridFilterDialogViewModelGroupingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridFilterDialogViewModelGroupingDescriptionMetadata, _super);
    function GridFilterDialogViewModelGroupingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.b = function (a) {
        if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        if (a.k(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.c = function (a) {
        a.item("StartIndex", "Number:int");
        a.item("EndIndex", "Number:int");
        a.item("IsOrGrouping", "Boolean");
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.d = function (a) {
        GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
        a.ae("GridFilterDialogViewModelGrouping", function () { return new GridFilterDialogViewModelGroupingDescription(); });
        a.ad("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
}(Base));
export { GridFilterDialogViewModelGroupingDescriptionMetadata };
